#
# spec file for package python-MarkupSafe
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-MarkupSafe
Version:        1.1.1
Release:        2.5
URL:            https://github.com/pallets/markupsafe
Summary:        Implements a XML/HTML/XHTML Markup safe string for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/M/MarkupSafe/MarkupSafe-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%ifpython2
Provides:       %{oldpython}-markupsafe = %{version}
Obsoletes:      %{oldpython}-markupsafe < %{version}
%endif

%python_subpackages

%description
Implements a unicode subclass that supports HTML strings. This can be used to
safely encode strings for dynamically generated web pages.

%prep
%setup -q -n MarkupSafe-%{version}
rm docs/make.bat docs/Makefile docs/conf.py docs/requirements.txt

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_expand rm %{buildroot}%{$python_sitearch}/markupsafe/_speedups.c

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python -m pytest

%files %{python_files}
%license LICENSE.rst
%doc README.rst docs/
%{python_sitearch}/markupsafe/
%{python_sitearch}/MarkupSafe-%{version}-py*.egg-info

%changelog
* Tue Mar  5 2019 tchvatal@suse.com
- Update to 1.1.1:
  * Fix segfault when __html__ method raises an exception when using the C speedups. The exception is now propagated correctly. (#109)
* Thu Feb 21 2019 jayvdb@gmail.com
- Update to v1.1.0
  - Drop support for Python 2.6 and 3.3.
  - Build wheels for Linux, Mac, and Windows, allowing systems without
    a compiler to take advantage of the C extension speedups
  - Use newer CPython API on Python 3, resulting in a 1.5x speedup
  - ``escape`` wraps ``__html__`` result in ``Markup``, consistent with
    documented behavior
- Switch to using pytest in %%check as setup.py test no longer works
- Use more precise URL https://github.com/pallets/markupsafe
- Add docs/ to %%doc, including the changelog
- Remove AUTHORS from %%doc, removed upstream in 6247e015
* Mon Jan 14 2019 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Tue Apr  4 2017 jmatejek@suse.com
- update source url
- fix obs/prov to refer to old python
- drop _speedups.c from installed directory
* Wed Mar 22 2017 tbechtold@suse.com
- Add missing BuildRequires for python-rpm-macros
* Wed Mar 22 2017 tbechtold@suse.com
- update to 1.0.0
  + No upstream changelog
- Switch to singlespec approach
* Tue Jul 15 2014 toddrme2178@gmail.com
- Update to 0.23
  + No upstream changelog
* Thu May  8 2014 toddrme2178@gmail.com
- Update to 0.21
  + No upstream changelog
  - ------------------------------------------------------------------
* Thu Mar 13 2014 mcihar@suse.cz
- update to 0.19:
  + Various Python 3.x fixes
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jun 25 2013 dmueller@suse.com
- update to 0.18:
  + Fixed interpolation on tuples
  + Varios Python 3.x fixes
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3 package added
- minor spec improvement
* Thu Sep  8 2011 andrea.turrini@gmail.com
- Fixed typo in description of python-MarkupSafe.spec
* Thu Sep  1 2011 saschpe@suse.de
- Update to 0.15
- Changed license to BSD-3-Clause
- Renamed to python-MarkupSafe (from python-markupsafe)
* Mon Aug 30 2010 jfunk@funktronics.ca
- Update to 0.11
    Since MarkupSafe 0.10 there is now also a separate escape function
    called `escape_silent` that returns an empty string for `None` for
    consistency with other systems that return empty strings for `None`
    when escaping (for instance Pylons' webhelpers).
* Thu Jul  1 2010 jfunk@funktronics.ca
- Initial release
